@@ -39,6 +39,7 @@ from tencentcloud.common.http.request import RequestInternal
 from tencentcloud.common.profile.client_profile import ClientProfile, RegionBreakerProfile
 from tencentcloud.common.sign import Sign
 from tencentcloud.common.circuit_breaker import CircuitBreaker
+from tencentcloud.common.retry import NoopRetryer
 
 warnings.filterwarnings("ignore", module="tencentcloud", category=UserWarning)
 
@@ -400,6 +401,13 @@ class AbstractClient(object):
             elif key == 'retry':
                 e[key] = int(val)
 
+    @staticmethod
+    def _process_response_json(resp, resp_type):
+        resp_obj = json.loads(resp.content)["Response"]
+        model = resp_type()
+        model._deserialize(resp_obj)
+        return model
+
     def _call(self, action, params, options=None, headers=None):
         if headers is None:
             headers = {}
@@ -421,11 +429,16 @@ class AbstractClient(object):
         return self.request.send_request(req)
 
     def call(self, action, params, options=None, headers=None):
-        resp = self._call(action, params, options, headers)
-        self._check_status(resp)
-        self._check_error(resp)
-        logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp))
-        return resp.content
+
+        def _call_once():
+            resp = self._call(action, params, options, headers)
+            self._check_status(resp)
+            self._check_error(resp)
+            logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp))
+            return resp
+
+        retryer = self.profile.retryer or NoopRetryer()
+        return retryer.send_request(_call_once).content
 
     def _call_with_region_breaker(self, action, params, options=None, headers=None):
         endpoint = self._get_endpoint()
@@ -501,17 +514,44 @@ class AbstractClient(object):
         :type options: dict
         :param options: request options, like {"SkipSign": False, "IsMultipart": False, "IsOctetStream": False, "BinaryParams": []}
         """
-        resp = self._call(action, params, options, headers)
-        self._check_status(resp)
-        self._check_error(resp)
-        logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp))
-        return json.loads(resp.content)
+
+        def _call_once():
+            resp = self._call(action, params, options, headers)
+            self._check_status(resp)
+            self._check_error(resp)
+            logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp))
+            return resp
+
+        retryer = self.profile.retryer or NoopRetryer()
+        return json.loads(retryer.send_request(_call_once).content)
 
     def call_sse(self, action, params, headers=None, options=None):
-        resp = self._call(action, params, options, headers)
-        self._check_status(resp)
-        self._check_error(resp)
-        return self._process_response_sse(resp)
+        def _call_once():
+            resp = self._call(action, params, options, headers)
+            self._check_status(resp)
+            self._check_error(resp)
+            return resp
+
+        retryer = self.profile.retryer or NoopRetryer()
+        return self._process_response_sse(retryer.send_request(_call_once))
+
+    def _call_and_deserialize(self, action, params, resp_type, headers=None, options=None):
+        def _call_once():
+            resp = self._call(action, params, options, headers)
+            self._check_status(resp)
+            self._check_error(resp)
+            return resp
+
+        retryer = self.profile.retryer or NoopRetryer()
+        return self._process_response(retryer.send_request(_call_once), resp_type)
+
+    def _process_response(self, resp, resp_type):
+        if resp.headers.get('Content-Type') == "text/event-stream":
+            logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp, format_body=False))
+            return self._process_response_sse(resp)
+
+        logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp))
+        return self._process_response_json(resp, resp_type)
 
     def set_stream_logger(self, stream=None, level=logging.DEBUG, log_format=None):
         """
